function unwrapped_phase=unwrapl(wrapped_phase,threshold,step,direction);
//
// Description:
// Unwraps a phased image (gray levels) of the simpliest manner: linearly
// 1) computes a linear matrix: 1st line is read from left to right,
// 2nd line is read from right to left, etc...
// 2) compares the gradient to a threshold (0.5 is the default):
// add or substract 1 to ensure phase continuity.
// 3) rebuilds a image matrix from the linear matrix
// 4) step: don't authorize 2 phase jumps which are too close from one another
// 5) direction: h (horizontal: default) or v (vertical)
// 6) jumps is the map containing the number of phase jumps
// 
// Very simple and fast algorithm. But very noise sensitive.
// Images to treat should be of excellent quality.
// 
// Note: the unwrapped_phase is not in the 0-1 range. Normalize is needed
// before displaying it.
//
// AUTHOR
//    Jocelyn DRUEL  <jocelyn.drual1@libertysurf.fr>
//    Labo Photonique, Lycee Gustave Eiffel
//    59280 ARMENTIERES (FRANCE)
//
// LICENSE: GNU GPL
// $Revision: 1.2 $ $Date: 2004/02/07 00:46:01 $

if argn(2)==0 then
  error("unwrapl(wrapped_phase[,threshold,step,direction])")
end;


if ~exists('threshold','local') then
  threshold=0.5
end
if ~exists('step','local') then
  step=0;
end
if ~exists('direction','local') then
  direction='h'
end



if direction=="v" then
  wrapped_phase=wrapped_phase';
end;//default:horizontal scanning



//build a linear matrix (lm)
lm=[];
for i=1:size(wrapped_phase,'r')
  if modulo(i,2)>0.5 then
    lm=[lm wrapped_phase(i,:)];//pair > from left to right
  else lm=[lm wrapped_phase(i,$:-1:1)];//odd > from right to left
  end;//if
  
end;//for


//calculate gradient
grad=zeros(lm);
grad(2:$)=lm(2:$)-lm(1:$-1);


//see if we have to add or substract  1 to the phase
lm_unwrap=zeros(lm);
myshift=zeros(lm_unwrap);
distance=0;//distance form the last phase jump
inc=0;//increase or decrease number of jumps
jumps=zeros(lm_unwrap);//map of jumps


for i=1:size(lm,'c')
  if (grad(i)>threshold)&(distance>=step) then 
    myshift(i)=myshift(i)-1;
    inc=inc-1;
    distance=0;
  elseif (grad(i)<-threshold)&(distance>step) then 
    myshift(i)=myshift(i)+1;
    inc=inc+1;
    distance=0;
  end;//if
  jumps(i)=inc;
  distance=distance+1;
end;//for


lm_unwrap=lm+jumps;


  

//Rebuild a rectanguler matrix
unwrapped_phase=[];

for i=1:size(wrapped_phase,'r')
  if modulo(i,2)>0.5 then
   unwrapped_phase(i,1:size(wrapped_phase,'c'))=lm_unwrap(1+(i-1)*size(wrapped_phase,'c'):i*size(wrapped_phase,'c'));
 else 
   unwrapped_phase(i,1:size(wrapped_phase,'c'))=lm_unwrap(i*size(wrapped_phase,'c'):-1:1+(i-1)*size(wrapped_phase,'c'));
   end;//if

end;


if direction=="v" then
  unwrapped_phase=unwrapped_phase';
end;//default:horizontal scanning

endfunction;
