.\"
.\" $Revision: 1.14 $  $Date: 2004/02/05 07:59:09 $
.\"
.TH CURVATURE 1 "January 2002" "SIP Toolbox"
.SH NAME
curvature \- curvature of a contour
.SH "SYNOPSIS"
.nf
K = curvature(BW [,sigma, delta])
K = curvature(x,y [,sigma, delta])
.fi
.SH PARAMETERS
.TP
.B K
vector containing the curvature of the contour at each point.
.TP
.B BW
Binary image containing only one object (0 for background, 1 for
object).
.TP
.B x and y
vectors, storing the parametrized contour.
.TP
.B sigma
standard deviation of the gaussian function used to smooth the
contour before computing the curvature. Defaults to 5.
.TP
.B delta
a double number, the time between samples (delta t), and defaults to 1. 
.SH DESCRIPTION
Function \fBcurvature\fR calculates the curvature at each point
of a binary contour, using FFT and a formula from differential geometry.
.SH EXAMPLE
.nf
initial_dir = PWD;
chdir (SIPDIR + 'images');

Img = imread('star.bmp');
xbasc()
imshow(Img,2);
k = curvature(Img,13);  // 13 sigma (shape is smoothed so curvature exists)
xbasc()
plot(k)
//
// observe there are six curvature peaks,
// corresponding to the six peaks of the star. There
// is one peak half at 0 and half at about 450.
// That's because the parametrization of
// the contour started at the highest peak and
// terminated there. Note also that the shape had to 
// be considerably smoothed so the curvature doesn't 
// blow up at the very sharp peaks of the star.
//

chdir(initial_dir);
.fi
.SH REFERENCES
"Shape Analysis and Classification", L. da
F. Costa and R. M. Cesar Jr., CRC Press,
pp. 335-347.
.LP
"Differential Geometry of Curves and Surfaces", 
Manfredo P. do Carmo, Prentice Hall, 1976.
.SH AUTHORS
Ricardo Fabbri <rfabbri@if.sc.usp.br>
.SH AVAILABILITY
The latest version of the Scilab Image Processing toolbox can be
found at
.IP
\%http://siptoolbox.sourceforge.net
.SH "SEE ALSO"
follow, gsm, fftderiv
.\"
.\" SIP - Scilab Image Processing toolbox
.\" Copyright (C) 2002-2004  Ricardo Fabbri
.\"
.\" See the file COPYING for license-related issues
.\"
