.\"
.\" $Revision: 1.10 $  $Date: 2004/02/05 08:05:34 $
.\"
.TH EDGE 1 "January 2002" "SIP Toolbox"
.SH NAME
edge \- edge detection
.SH "SYNOPSIS"
.nf
E = edge(Img)
E = edge(Img, named_args)
E = edge(Img, method)
E = edge(Img, method, thresh)
E = edge(Img, method, thresh, direction)
E = edge(Img, method, thresh, direction, sigma)
.fi
.SH PARAMETERS
.TP
.B Img
M x N Grayscale (intensity) image in any range.
.TP
.B method
may be \fB'sobel'\fR(default), \fB'prewitt'\fR or \fB'fftderiv'. Other
methods will appear in the future. 
.TP
.B thresh
sets the threshold level, from \fB0 to 1\fR. Defaults to 0.5. If negative, 
then the output image, \fIE\fR, will have the un-thresholded
gradient image.
.TP
.B direction
may be \fB'horizontal'\fR, \fB'vertical'\fR or \fB'both'\fR(default). This
determines the direction to compute the image gradient.
.TP
.B sigma
Controls the ammount of high-frequency attenuation in some methods
(only the 'fftderiv' method uses this parameter). This can be
used to obtain different levels of detail and to filter out
high-frequency noise. Defaults to 1.
.TP
.B <named_args>
this is a sequence of statements key1=value1, key2=value2,...
where key1, key2,... can be any of the optional arguments above,
in any order.
.SH DESCRIPTION
The function \fBedge\fR performs edge detection on a grayscale intensity
image. The user may set the method, the threshold level and the
direction of the edge detection.
.LP
\fBedge(Img)\fR 
Detects edges in \fIImg\fR, using the sobel gradient estimator, 0.5
threshold level and in both horizontal and vertical directions. 
.LP
The other parameters are optional and non-positional. That is, they
may be passed to the function by their name. The following example
illustrates this.

.SH EXAMPLE
.nf
initial_dir = PWD;
chdir (SIPDIR + 'images');

Img = imread('tru.jpg');
Img = im2gray(Img);
xbasc()
imshow(Img);

e = edge(Img);  // sobel, thresh = 0.5
xbasc()
imshow(e,2)

e = edge(Img,'prewitt'); // thresh = 0.5
xbasc()
imshow(e,2)

e = edge(Img,'fftderiv', 0.4);  // FFT gradient method; 0.4 threshold
xbasc()
imshow(e,[])

// It is useful to thin the edges, eliminating redundant pixels:
e = thin(e);
xbasc()
imshow(e,[])

e = edge(Img,'fftderiv',sigma=3,thresh=-1); // thicker edges, no threshold
xbasc()
imshow(e,[])

e = edge(Img,thresh=-1);
xbasc()
imshow(e,[])

chdir(initial_dir);
.fi
.SH REMARKS
In the future, more sophisticated algorithms like Canny and
Marr-Hildreth will be available, while maintaining the same interface.
.SH REFERENCES
"Shape Analysis and Classification", L. da
F. Costa and R. M. Cesar Jr., CRC Press, section 3.3.
.SH AUTHORS
Ricardo Fabbri <rfabbri@if.sc.usp.br>
.SH AVAILABILITY
The latest version of the Scilab Image Processing toolbox can be
found at
.IP
\%http://siptoolbox.sourceforge.net
.SH "SEE ALSO"
bwborder, mogrify, im2gray, imconv, mkfilter
.\"
.\" SIP - Scilab Image Processing toolbox
.\" Copyright (C) 2002-2004  Ricardo Fabbri
.\"
.\" See the file COPYING for license-related issues
.\"
