.\"
.\" $Revision: 1.10 $  $Date: 2004/02/03 08:45:50 $
.\"
.TH FFTDERIV 1 "March 2002" "SIP Toolbox"
.SH NAME
fftderiv \- derivative of a vector using FFT
.SH "SYNOPSIS"
.nf
[Dy, DY] = fftderiv(y, [n , sigma, delta, in, out])
[Dy, DY] = fftderiv(y, <named_args>)
.fi
.SH INPUT PARAMETERS
.TP
.B y
vector containing a periodic window of a function to be differentiated.
.TP
.B n
the order of the derivative. It is 1 for 1st derivative, 2 for 2nd
derivative, and so on.
.TP
.B sigma
the standard deviation of the gaussian kernel used to smooth the input.
If \fIsigma\fR is zero, \fBfftderiv\fR will not smooth the 
input. (Defaults to 5)
.TP
.B delta
a double number. If the input is in the time domain, 
this is the time between samples (delta t), and defaults to 1. 
If the input is in the frequency domain, this is the frequency
increment between samples (delta f), and defaults to 1/N, where N is
the number of samples. 
.TP
.B in
indicates if the input, \fIx\fR, is a function of time (no FFT has been applied) 
or frequency (FFT has already been applied). 
Can be 'time' or 'frequency'. (Defaults to 'time')
.TP
.B out
indicates if the output, \fIxsm\fR, is a function of time (inverse
FFT will be applied) or frequency (inverse FFT will not be applied). 
Can be 'time' or 'frequency'. (Defaults to 'time')
.TP
.B <named_args>
This is a sequence of statements key1=value1, key2=value2,...
where key1, key2,... can be any of the optional arguments above, in any order.
.SH OUTPUT PARAMETERS
.TP
.B Dy
the derivative vector in "time" or "frequency" domain. 
.TP
.B FDy
the derivative vector in "frequency" domain.
.SH DESCRIPTION
Function \fBfftderiv\fR performs the \fIn\fR-th derivative of a periodic function,
stored in a vector, using FFT.
The optional arguments \fIin\fR and \fIout\fR enables the user to reuse
previously done FFTs. Here are some possible uses of gsm:
.TP
.B Dy = fftderiv(y)
\fIn defaults to 1, \fR\fIsigma\fR defaults to 5, 
\fIin\fR and \fIout\fR both defaults to 'time'.
.TP
.B Dy = fftderiv(y,2,3)
\fIn\fR equals 2, \fIsigma\fR equals 3, 
\fIin\fR and \fIout\fR both defaults to 'time'.
.TP
.B Dy = fftderiv(y,sigma=3, in='frequency',out='frequency')
\fIn\fR dafaults to 1,
\fIy\fR in frequency domain (fft has already been done).
\fIDy\fR in frequency domain (inverse fft is NOT done by gsm)
.LP
In all above examples, \fIFDy\fR is in the frequency domain. It is the second output
parameter, and thus it was discarded in the above examples.
.SH EXAMPLE
.nf
step = 2*%pi/100;
y = sin(step:step:2*%pi);  // from 2pi/100 to 2pi
xbasc()
plot(y);
// 1st derivative, a sigma of 3 steps to the left and to the right
d = fftderiv(y,1,3*step,step);
xbasc()
plot(d)  // a cosine period
.fi
.SH REMARKS
For a derivative without noises,
the vector \fIy\fR must be an exact period of a continuous periodic function,
i.e., its repetition has to be continuous. A direct way for checking 
this is to plot z = [y y] and look close in the middle. If there is
not a minimal discontinuity, then \fBfftderiv\fR will certainly work
without need for smoothing.
.LP
\fIy\fR should be smoothed before using \fBfftderiv\fR so the
derivative is less sensitive to discontinuities and aliasing.
For an estimation of the \fBsigma\fR parameter, please refer to
the references below.
.SH REFERENCES
"Shape Analysis and Classification", L. da
F. Costa and R. M Cesar Jr., CRC Press,
pp. 335-347.
.LP
"1D and 2D Fourier-based approaches to numeric curvature estimation
and their comparative performance assessment", L.\ F.\ Estrozi, L.\ \
G.\ R.\ Filho, A.\ G.\ Campos and L.\ da F.\ Costa,
Digital Signal Processing, 2002, accepted paper.
.SH AUTHORS
Ricardo Fabbri <rfabbri@if.sc.usp.br>
.SH AVAILABILITY
The latest version of the Scilab Image Processing toolbox can be
found at
.IP
\%http://siptoolbox.sourceforge.net
.SH "SEE ALSO"
follow, gsm, fftshift, curvature
.\"
.\" SIP - Scilab Image Processing toolbox
.\" Copyright (C) 2002-2004  Ricardo Fabbri
.\"
.\" See the file COPYING for license-related issues
.\"
