.\"
.\" $Revision: 1.9 $ $Date: 2004/02/05 09:24:16 $
.\"
.TH FOLLOW 1 "January 2002" "SIP Toolbox"
.SH NAME
follow \- a contour follower
.SH "SYNOPSIS"
.nf
[x,y] = follow(Img)
[x,y] = follow(Img, 4)    
[x,y] = follow(Img, 8)
.fi
.SH PARAMETERS
.TP
.B Img
binary array,  1 for object and 0 for background (double
precision)
.TP
.B x and y
vectors, storing the parametrized contour.
.SH DESCRIPTION
Function \fBfollow\fR extracts parametric contours of binary objects.
This is useful for further extracting object features such as
curvature and bending energy.
.LP
It is assumed that \fIImg\fR has only one object. 
.LP
\fIx\fR and \fIy\fR both store the parametrized contour. That
is, (x(i),y(i)) is a point of the contour, where the coordinate
system is assumed as starting from bottom-left corner (0,0) to
uper-right corner of the image. To get the (row,col) matrix 
coordinates, use the transformation below: 
.IP
      row = size(Img,'r') - y
      col = x+1
.LP
The second argument is an optional parameter, being 4 or 8
depending if the border following is to be made 
in 4- or 8-neighborhood sequence, yielding a 4-
or 8-connected contour.
.LP
\fBfollow(Img)\fR 
equals \fBfollow(Img, 8)\fR.
.SH EXAMPLE
.nf
initial_dir = PWD;
chdir (SIPDIR + 'images');

Img = imread('star.bmp');
xset('window',0)
xbasc()
imshow(Img,2);
[x,y] = follow(Img);
xset('window',1)
xbasc()
plot2d(1:size(x,'*'),x,2);
plot2d(1:size(y,'*'),y,1);

chdir(initial_dir);
.fi
.SH REFERENCE
"Shape Analysis and Classification", L. da
F. Costa and R. M Cesar Jr., CRC Press,
pp. 335-347.
.SH AUTHORS
Ricardo Fabbri <rfabbri@if.sc.usp.br>
.SH AVAILABILITY
The latest version of the Scilab Image Processing toolbox can be
found at
.IP
\%http://siptoolbox.sourceforge.net
.SH "SEE ALSO"
unfollow, gsm, bwborder, curvature
.\"
.\" SIP - Scilab Image Processing toolbox
.\" Copyright (C) 2002-2004  Ricardo Fabbri
.\"
.\" See the file COPYING for license-related issues
.\"
