.\"
.\" $Revision: 2.3 $  $Date: 2004/02/03 08:45:50 $
.\"
.TH GSM 1 "March 2002" "SIP Toolbox"
.SH NAME
gsm \- 1D gaussian smoothing
.SH "SYNOPSIS"
.nf
[xsm, Xsm] = gsm(x [, sigma, delta, in, out])
[xsm, Xsm] = gsm(x, <named_args>)
.fi
.SH INPUT PARAMETERS
.TP
.B x
the vector to be smoothed (row or column vector), real or complex.
.TP
.B sigma
the standard deviation of the gaussian kernel.
If \fIsigma\fR is zero, \fBgsm\fR returns the input vector
unaltered in xsm. (Defaults to 5)
.TP
.B delta
a double number. If the input is in the time domain, 
this is the time between samples (delta t), and defaults to 1. 
If the input is in the frequency domain, this is the frequency
increment between samples (delta f), and defaults to 1/N, where N is
the number of samples. 

.TP
.B in
indicates if the input, \fIx\fR, is a function of time (no FFT has been applied) 
or frequency (FFT has already been applied). 
Can be 'time' or 'frequency'. (Defaults to 'time')
.TP
.B out
indicates if the output, \fIxsm\fR, is a function of time (inverse
FFT will be applied) or frequency (inverse FFT will not be applied). 
Can be 'time' or 'frequency'. (Defaults to 'time')
.TP
.B <named_args>
This is a sequence of statements key1=value1, key2=value2,...
where key1, key2,... can be any of the optional arguments above (\fIsigma,
in, out\fR), in any order.
.SH OUTPUT PARAMETERS
.TP
.B xsm
the smoothed vector in "time" or "frequency" domain. 
.TP
.B Xsm
the smoothed vector in "frequency" domain.
.SH DESCRIPTION
Function \fBgsm\fR performs gaussian smoothing of the vector \fIx\fR, with
standard deviation \fIsigma\fR, using FFT.
The optional arguments \fIin\fR and \fIout\fR enables the user to reuse
previously done FFTs. Here are some possible uses of gsm:
.TP
.B
xsm = gsm(x)
\fIsigma\fR defaults to 5, \fIin\fR and \fIout\fR both defaults to 'time'.
.TP
.B
xsm = gsm(x,15)
\fIsigma\fR equals 15, \fIin\fR and \fIout\fR both defaults to 'time'.
.TP
.B
xsm = gsm(x,15, out='frequency')
\fIx\fR in time domain.
\fIxsm\fR in frequency domain (inverse fft is NOT done by gsm)
.TP
.B
xsm = gsm(x,15,in='frequency', out='frequency')
\fIx\fR in frequency domain (fft has already been done).
\fIxsm\fR in frequency domain (inverse fft is NOT done by gsm)
.TP
.B
xsm = gsm(x, 'frequency', delta=0.1)
\fIdelta f\fR is 0.1
\fIsigma\fR defaults to 5
\fIx\fR in frequency domain.
\fIxsm\fR in time domain (inverse fft is done by gsm)
.LP
In all above examples, \fIXsm\fR is in the frequency domain. It is the second output
parameter, and thus it was discarded in the above examples.

.SH EXAMPLE
.nf
initial_dir = PWD;
chdir (SIPDIR + 'images');

Img = imread('star.bmp');
xset('window',0);
xbasc()
imshow(Img,2);
[x,y] = follow(Img);  // get the parametric contour
xset('window',1)
xbasc()
t=1:size(x,'*');
plot2d(t,x,2);
plot2d(t,y,1);
xsm = gsm(x,15);  // gaussian-smooth the contour
ysm = gsm(y,15);
// builds an image from parametric contour:
Img2=unfollow(xsm,ysm,size(Img));
xset('window',0);
xbasc()
imshow(Img2,2);

chdir(initial_dir);
.fi
.SH AUTHORS
Ricardo Fabbri <rfabbri@if.sc.usp.br>
.SH AVAILABILITY
The latest version of the Scilab Image Processing toolbox can be
found at
.IP
\%http://siptoolbox.sourceforge.net
.SH "SEE ALSO"
gsm2d, fft
.\"
.\" SIP - Scilab Image Processing toolbox
.\" Copyright (C) 2002-2004  Ricardo Fabbri
.\"
.\" See the file COPYING for license-related issues
.\"
