.\"
.\" $Revision: 1.7 $  $Date: 2003/11/14 17:45:41 $
.\"
.TH IMCONV 1 "January 2002" "SIP Toolbox"
.SH NAME
imconv \- 2D convolution
.SH "SYNOPSIS"
.nf
Outm = imconv(Img, mask [, form])
.fi
.SH PARAMETERS
.TP
.B Img
M x N Grayscale (intensity) image in any range.
.TP
.B mask
n x n matrix, n odd. This is the spatial convolution kernel.
.TP
.B Outm
The convolved matrix (grayscale image).
.TP
.B form
determines the size of Outm. It assumes be one of the following
values:
.RS
.PD 0
.TP
.B 'same' 
Outm has the same size as the original image, M x N. 
The image is assumed to be 0 outside its bounds.
.TP
.B 'full' 
Outm contains the full convolution, (M+n-1) x (N+n-1).
The image is assumed to be 0 outside its bounds. 
.TP
.B 'valid' 
Outm contains only the results of the convolution which have been
computed within the bounds of \fIImg\fR. Outm will be (M-n+1) x (N-n+1).
.PD
.PP
.SH DESCRIPTION
Function \fBimconv\fR performs 2D spatial convolution of a grayscale
image and a mask.
.LP
\fBedge(Img)\fR 
Detects edges in \fIImg\fR, using the sobel gradient estimator, 0.5
threshold level and in both horizontal and vertical directions. 
.LP
The other parameters are optional and non-positional. That is, they
may be passed to the function by their name. The following example
illustrates this.
.SH EXAMPLE
.nf
initial_dir = PWD;
chdir (SIPDIR + 'images');

// Detect horizontal lines
h = [ -1  -1 -1
       2   2  2 
      -1  -1 -1]
img = imread('gra.jpg');
res = imconv(img,h);
imshow(res,[]);    
// Detect diagonal lines
d = [ -1  -1  2
      -1   2 -1 
       2  -1 -1]
res = imconv(img,d);
imshow(res,[]);

chdir(initial_dir);
.fi
.SH REMARKS
The kernel is not rotated by 180 degrees. This is in truth a
correlation operator, but in practice only symmetric kernels are used.
.SH AUTHORS
Ricardo Fabbri <rfabbri@if.sc.usp.br>, with help from
Scilab Group   <Scilab@inria.fr>
.SH AVAILABILITY
The latest version of the Scilab Image Processing toolbox can be
found at
.IP
\%http://siptoolbox.sourceforge.net
.SH "SEE ALSO"
mkfilter, edge
.\"
.\" SIP - Scilab Image Processing toolbox
.\" Copyright (C) 2002-2004  Ricardo Fabbri
.\"
.\" See the file COPYING for license-related issues
.\"
