.\"
.\" $Revision: 1.2 $  $Date: 2004/02/05 09:24:16 $
.\"
.TH IMCORRCOEF 1 "September 2003" "SIP Toolbox"
.SH NAME
imcorrcoef \- template matching by normalized correlation
.SH "SYNOPSIS"
.nf
C = imcorrcoef(Img, template)
.fi
.SH PARAMETERS
.TP
.B Img
M x N Grayscale image in any range.
.TP
.B template
n x n matrix, n odd. A small object to be found in the image.
.TP
.B C
The correlation coefficient image. Its highest value occurs where
the template matches exactly.

.SH DESCRIPTION
Function \fBimcorrcoef\fR performs template matching by 2D
correlation of a grayscale image and a template. This means the
template is compared to the image pixel-by-pixel, for every possible
translation of the template. The result is normalized to range from
-1 to +1. You may also use the absolute value of this measure.

This is an expensive calculation, and should be used only
for small templates. The object to be detected must appear in the
image with very little variation of rotation and scale. This is useful
if you can restrict the image capture to avoid those problems.

.SH EXAMPLE
.nf
//
// Let's detect the letter "B" in a license plate
//
img = gray_imread(SIPDIR+'images/plate.jpg');
xbasc(),  imshow(img);
template = gray_imread(SIPDIR+'images/template.jpg');
xbasc(),  imshow(template);

C = imcorrcoef(img, template);

xbasc();
imshow(img+2*(C==maxi(C)),[]);  // letter is detected!!

.fi
.SH AUTHORS
Ricardo Fabbri <rfabbri@if.sc.usp.br>

.SH AVAILABILITY
The latest version of the Scilab Image Processing toolbox can be
found at
.IP
\%http://siptoolbox.sourceforge.net
.SH "SEE ALSO"
imconv, mkfilter, edge
.\"
.\" SIP - Scilab Image Processing toolbox
.\" Copyright (C) 2002-2004  Ricardo Fabbri
.\"
.\" See the file COPYING for license-related issues
.\"
