.\"
.\" $Revision: 1.8 $ $Date: 2004/02/03 08:45:50 $
.\"
.TH IMFINFO 1 "January 2002" "SIP Toolbox"
.SH NAME
imfinfo \- image file information
.SH "SYNOPSIS"
.nf
info = imfinfo(filename)
info = imfinfo(filename, 'verbose')
.fi
.SH PARAMETERS
.TP
.B filename
A string, the image filename to be described. The extension
determines the type of the image.
.TP
.B 'verbose'
causes \fIimfinfo\fR to print image description on the screen.
.TP
.B info
A structure (Scilab typed list) containing the descriptions under each
of the following fields: 
.RS
.TP
.B FileName
need no comment.
.TP
.B FileSize
measured in bytes.
.TP
.B Format
"JPEG", "TIFF", "GIF", "BMP", etc.
.TP
.B Width
number of columns.
.TP
.B Height
number of rows.
.TP
.B Depth
bits per pixel.
.TP
.B StorageType
"truecolor" or "indexed".
.TP
.B NumberOfColors
size of the colormap. Equals to zero for truecolor images.
.TP
.B ResolutionUnit
"inch" or "centimeters".
.TP
.B XResolution
number of pixels per \fIResolutionUnit\fP in X direction.
.TP
.B YResolution
number of pixels per \fIResolutionUnit\fP in Y direction.
.PP
.SH DESCRIPTION
\fBimfinfo\fP is used to get a description from image files, without
reading the pixels into memory. A structure (Scilab typed list) is
returned with the information, which can be accessed by their names
(e.g. info.Depth, info.FileSize, ...).
The 'verbose' option causes the description to be printed in an 
organised manner.
.SH EXAMPLE
.nf
initial_dir = PWD;
chdir (SIPDIR + 'images');

info = imfinfo('example.png');     // reads information into a tlist
info.Depth                         // members are accessed by name
info.StorageType
imfinfo('example.png','verbose');  // pretty-print description

chdir(initial_dir);
.fi
.SH REMARKS
In theory, \fBimfinfo\fP will work with any raster image format. 
In practice, it has been tested only for BMP, GIF, JPEG, PNG, PCX, TIFF,
XPM, and MIFF. \fBimfinfo\fP will \fIprobably work\fP with other
formats, but in this case have not been tested by the 
developers of the SIP toolbox.
.SH "BUGS AND SHORTCOMINGS"
Images are stored in double precision matrices. Hopefully, the next release
will make usage of integer types.
.SH AUTHORS
Ricardo Fabbri <rfabbri@if.sc.usp.br>
.SH AVAILABILITY
The latest version of the Scilab Image Processing toolbox can be
found at
.IP
\%http://siptoolbox.sourceforge.net
.SH "SEE ALSO"
imwrite, imread, imshow
.\"
.\" SIP - Scilab Image Processing toolbox
.\" Copyright (C) 2002-2004  Ricardo Fabbri
.\"
.\" See the file COPYING for license-related issues
.\"
