.\"
.\" $Revision: 1.4 $  $Date: 2004/02/05 20:11:02 $
.\"
.TH IMNOISE 1 "AUGUST 2003" "SIP Toolbox"
.SH NAME
imnoise \- generate noise (salt & pepper, etc)
.SH "SYNOPSIS"
.nf
J = imnoise(I, type [,parameters])
.fi
.SH PARAMETERS
.TP
.B I
Input image (grayscale).
.TP
.B J
Noisy image (grayscale).
.TP
.B type
String having one of these values:
.br
 'salt & pepper': drop-out/On-off noise
.br
 'speckle': multiplicative noise
.br
 'gaussian': Gaussian white/additive noise
.br
 'localvar': Pixel-specific variance (Zero-mean Gaussian)
.TP
.B parameters
A sequence of parameters to control the noise distribution, depending
on the chosen type. If omitted, default values are used (see below).
.SH DESCRIPTION
\fBimnoise(Img, type)\fP adds a \fItype\fR of noise to the intensity image Img.
Optionally, you can control the noise parameters starting at the 3rd.
argument to imnoise. Here are example of noise types and their params:

\fBJ = imnoise(I,'salt & pepper',d)\fP adds drop-out noise, where d is
the noise density (probability of swapping a pixel). (default:
d=0.05).

\fBJ = imnoise(I,'salt & pepper', d, val)\fP does the same, but "val"
is the value of salt (defaults to maximum of image). If "val" == 0,
then pixels are replaced by uniformly random gray values.

\fBJ = imnoise(I,'gaussian',m,v)\fP adds Gaussian additive noise
of mean m and variance v. (default: m=0 and v=0.01)

\fBJ = imnoise(I,'localvar',V)\fP additive zero-mean Gaussian
noise where the variance at Img(i,j) is V(i,j).

\fBJ = imnoise(I,'speckle',v)\fP adds multiplicative noise, using J =
I+ noise*I, where noise is uniformly distributed with mean 0 and
variance v. (default: v=0.04)

The mean and variance parameters are specified as if image
intensities went from 0 to 1. By default, we consider that "1"
corresponds to the maximum intensity value of the image. If you want
to change this for 'gaussian' and 'speckle', pass an extra parameter
at the end of the argument list. For instance, your image may have
maximum intensity 180 even though the grayscale range is 0-1:

\fBJ = imnoise(I,'gaussian', m, v, val)\fP

\fBJ = imnoise(I,'speckle', v, val)\fP

.SH EXAMPLE
.nf
xset('auto clear', 'on');
A = gray_imread(SIPDIR + 'images/gra.jpg');
imshow(A);

N = imnoise(A,'salt & pepper');
imshow(N,[]);

N = imnoise(A,'salt & pepper',0.3);
imshow(N,[]);


// Replace pixel by independent random value:
N = imnoise(A,'salt & pepper',0.3,0);
imshow(N,[]);

// Replace pixel by *dependent* random value:
N = imnoise(A,'speckle');
imshow(N,[]);

xset('auto clear', 'off');
.fi
.SH REFERENCES
"Noise Generation", The Hypermedia Image Processing Reference
(HIPR), R. Fisher, S. Perkins, A. Walker and E. Wolfart,
University of Edinburgh
.br
http://www.dai.ed.ac.uk/HIPR2/noise.htm
.SH AUTHORS
Ricardo Fabbri  <rfabbri@if.sc.usp.br>
.SH AVAILABILITY
The latest version of the Scilab Image Processing toolbox can be
found at
.IP
\%http://siptoolbox.sourceforge.net
.SH "SEE ALSO"
mogrify '-noise' flag, mkfilter, gsm2d
.\"
.\" SIP - Scilab Image Processing toolbox
.\" Copyright (C) 2002-2004  Ricardo Fabbri
.\"
.\" See the file COPYING for license-related issues
.\"
