.\"
.\" $Revision: 1.11 $ $Date: 2004/02/05 09:24:16 $
.\"
.TH IMSHOW 1 "January 2002" "SIP Toolbox"
.SH NAME
imshow \- displays images in scilab graphic window
.SH "SYNOPSIS"
.nf
imshow(Img)      
imshow(Img,n)   
imshow(Img,[low high]) 
imshow(Img,Map)  
imshow(RGBImg)
imshow filename
imshow(Img, arg2 [, strf])
.fi
.SH PARAMETERS
.TP
.B filename
A String, the image filename to be displayed. The extension
determines the type of the image.
.TP
.B Img
MxN matrix, a grayscale (0-1 range) or pseudo-color/indexed (1-Ncolors range) 
image.
.TP
.B n
A scalar, the number of levels of gray to display \fIImg\fR.
.TP
.B [low high]
1x2 array corresponding to the grayscale range to be considered.
.TP
.B Map
Mx3 matrix containing the image colormap (for indexed images). Entries
may range from 0 to 1
.TP
.B RGBImg 
MxNx3 hypermatrix in 0-1 range.
.TP
.B strf
this is used to e.g. put axes around your image. See the plot2d help page.
You may use this optional parameter in the assignment style, as in:
.nf
   imshow(img, strf='041')   //same as imshow but draw axes
.fi
.SH DESCRIPTION
\fBimshow(Img,n)\fP displays \fIImg\fR using \fIn\fR gray
levels. \fIImg\fR is an MxN matrix in 0 - (n-1) range. 
If \fIn\fR is omitted, it will be assumed to be 256.
.LP
\fBimshow(Img,[low high])\fR 
displays \fIImg\fR using a grayscale 
within the specified range. Elements <= \fIlow\fR will map onto black, 
Elements >= \fIhigh\fR
will map onto white, and elements in between will map as a shade of
gray. If an empty matrix '[]' is used, [low,high] will be assumed to
be [mini(Img), maxi(Img)].
.LP
\fBimshow(Img,Map)\fP displays \fIImg\fP using the specified colormap.
.LP
\fBimshow(RGBImg)\fP displays the \fIRGBImg\fP MxNx3 (0-1) truecolor image.
.LP
\fBimshow(filename)\fP displays the image (\fIfilename\fP) in scilab
graphic. Any raster image format is accepted (see REMARKS section).
.SH EXAMPLE
.nf
initial_dir = PWD;
chdir (SIPDIR + 'images');

a = rand(100,100);   // create random image
xbasc();
imshow(a);

imshow(a*255 + 1,hotcolormap(256));
imshow(a,[0.3 0.6]);
imshow(a,[]);   
xbasc();
imshow('example.png');

chdir(initial_dir);
.fi
.SH REMARKS
In theory, \fBimshow(filename)\fP will work with any raster image format. 
In practice, it has been tested only for BMP, GIF, JPEG, PNG, PCX, TIFF,
XPM, and MIFF. Displaying other file formats will \fIprobably work\fP, but 
this case have not been tested by the developers of the SIP toolbox.
.SH "BUGS AND SHORTCOMINGS"
The display of truecolor images is somewhat inefficient.
.LP
Images are stored in double precision matrices. Hopefully, the next release
will make usage of integer types.
.SH AUTHORS
Ricardo Fabbri <rfabbri@if.sc.usp.br>
.SH AVAILABILITY
The latest version of the Scilab Image Processing toolbox can be
found at
.IP
\%http://siptoolbox.sourceforge.net
.SH "SEE ALSO"
imread, imwrite, imfinfo, xgetpixel
.\"
.\" SIP - Scilab Image Processing toolbox
.\" Copyright (C) 2002-2004  Ricardo Fabbri
.\"
.\" See the file COPYING for license-related issues
.\"
