.\"
.\" $Revision: 1.3 $  $Date: 2004/02/05 09:24:16 $
.\"
.TH 1 "March 2003" "SIP Toolbox"
.SH NAME
imvariance \- calculates the variance of an image
.SH "SYNOPSIS"
.nf
variance_matrix = imvariance(image)
.fi
.SH PARAMETERS
.TP
.B image
A gray-level image.

.SH DESCRIPTION
This function computes a matrix containing the variance of each point of
an image.

The variance is the sum of the absolute value of the differences between 
the central pixel and its neighbours:

variance=sum(|x(neighbour)-x(central)|)

A low variance value means a pixel is not very different
from its neigbours (in all directions).

This property can be used to unwrap phased images.  In case of a
"path-following algorithm", the variance can be a "merit function"
used to determine which pixels should be connected first.  This
"merit function" is much more noise immune than a "merit function"
based on a laplace kernel.

This algorithm calculates the variance everywhere
even on the edges.
In some cases, consider multiplying by a mask like this 
.nf
 [8/3 8/5 8/5...;
  8/5   1   1...;
.fi
so that edge values are really significatives.


.SH EXAMPLE
.nf
stacksize(1e7); // images are very much memory consumming...

varian=imvariance(imread(SIPDIR+'images/photonics/pyramide_wrapped.jpg'));

imshow(varian/max(varian));// high levels (blank on the image) 
				//represent points where intensity
				//changes quickly

.fi
.SH AUTHORS
Jocelyn DRUEL <jocelyn.druel1@libertysurf.fr>
.SH AVAILABILITY
The latest version of the Scilab Image Processing toolbox can be
found at
.IP
\%http://siptoolbox.sourceforge.net
.SH "SEE ALSO"
unwrapl, mkfilter('laplace1')
.\"
.\" SIP - Scilab Image Processing toolbox
.\" Copyright (C) 2002-2004  Ricardo Fabbri
.\"
.\" See the file COPYING for license-related issues
.\"
