.TH MINMAX 1 "February 2003" "SIP Toolbox"
.SH NAME
minmax \- Min/Max algorithm for noise removal from images
.SH "SYNOPSIS"
.nf
Output = minmax(Input, [NSteps, StepSize, Adapt, NonAdaptThreshold, 
                  IntMaskSize, ExtMaskSize])
.fi
.SH INPUT PARAMETERS
.TP
.B Input
a matrix containing a gray-scale image to be filtered by min/max algorithm.
.TP
.B NSteps
number of steps to perform. Default is 10.
.TP
.B StepSize
the step increment for the iterative procedure. Default is 0.05.
.TP
.B Adapt
indicates if the algorithm should adapt itself to the local image gray level
or if it considers the NonAdaptThreshold value for defining light and dark
regions. Default is FALSE.
.TP
.B NonAdaptThreshold
If Adapt is FALSE, intensity values greater than NonAdaptThreshold will be
considered as light regions.
.TP
.B IntMaskSize
Size of the Internal window in which curvature values will be taken into
account for deciding Min or Max curvature flow. Default is 1.
.TP
.B ExtMaskSize
Size of the External window in which curvature values will be taken into
account for deciding Min or Max curvature flow in the \fIAdapt\fI mode.
Default is 0.
.SH OUTPUT PARAMETERS
.TP
.B Output
a matrix containing the filtered image.
.SH DESCRIPTION
Function \fBminmax\fR filters a gray-scale image using curvature-guided 
surface evolution. Object borders remain sharp while low-scale noise is
removed.
.IP
.SH EXAMPLE
.nf
M = gray_imread(SIPDIR+'images/noisypoly.bmp');
subplot(1,2,1);
imshow(M);
new_M = minmax(M, NSteps=30);
subplot(1,2,2);
imshow(new_M);
.fi
.SH REFERENCES
"Image Processing via Level Set Curvature Flow ", Malladi, R.,
and Sethian, J.A., Proceedings of the National Academy of Sciences,
Vol. 92(15), pp. 7046-7050, July 1995
.br
http://math.berkeley.edu/~sethian/Movies/Movienoiseremoval.html
.SH AUTHORS
Leandro Estrozi (lfestrozi@if.sc.usp.br)
.SH AVAILABILITY
The latest version of the Scilab Image Processing toolbox can be
found at
.IP
\%http://siptoolbox.sourceforge.net
.SH "SEE ALSO"
curvature, curvature2d, mogrify
.\"
.\" SIP - Scilab Image Processing toolbox
.\" Copyright (C) 2002-2004  Ricardo Fabbri
.\"
.\" See the file COPYING for license-related issues
.\"
