.\"
.\" $Revision: 1.8 $  $Date: 2004/02/03 08:45:50 $
.\"
.TH MKFILTER 1 "March 2003" "SIP Toolbox"
.SH NAME
mkfilter \- returns popular 2D convolution kernels
.SH "SYNOPSIS"
.nf
K = mkfilter(name)
.fi
.SH PARAMETERS
.TP
.B name
a string, the name of the filter mask. May be 'sobel', 'prewitt', 'laplace1',
\'laplace2', 'laplace3','sh1' (or 'sharp1'), 'sh2' (or 'sharp2'), 'low-pass',
\'mean', 'circular', 'circular-mean'.
In the future there will be more options.
.TP
.B K
a 2D array containing the convolution kernel.
.SH DESCRIPTION
\fBmkfilter\fP builds well-known 2D filter "masks" (kernels), such as
sobel, prewitt, mean, etc. to be used together with a function such
as \fIimconv\fR.

\fBK = mkfilter('sobel')\fP returns a 3x3 edge-finding and y-derivative approximation filter.
To find vertical edges, use -K'.

\fBK = mkfilter('prewitt')\fP returns another 3x3 edge-finding and y-derivative 
approximation filter.
To find vertical edges, use -K'.

\fBK = mkfilter('laplace1')\fP returns a 3x3 kernel which shows points of
an image where intensity is varying quickly.
The "laplacien" of an image is the two-dimensionnal second derivative.
Because images are discrete (and not continuous), the "laplacien" can
only be approximated.
The 3 different kernels often used to estimate it are given
by "laplace1", "laplace2" and "laplace3".
These kernels can be used to detect edges of an image.

\fBK = mkfilter('sh1')\fP: "sharp enhancer". Returns a 3x3 kernel which renforce high frequencies
of the image: it accentuates the variations of a pixel compared to its neighbours.
Problem: it enhances the noise too (it may be useful to denoise the image before).

\fBK = mkfilter('sh2')\fP has the same effect than "sh1" but its coefficients are
more powerfull.

\fBK = mkfilter('low-pass')\fP : this is a low-pass filter.
The goal is inverse of sharp enhancer filters - the image is smoothed.
This kernel is only one of the possible kernels.

\fBK = mkfilter('mean')\fP : this is another low-pass filter.
The mean value of the central pixel and its neighbours is affected at
the central pixel.

\fBK = mkfilter('circular',rad)\fP is an euclidean circular mask with 
radius "rad" pixels, whose elements are all 1.

\fBK = mkfilter('circular-mean',rad)\fP is a low pass filter,
the same as 'circular', but the matrix K is divided by the number
of 1-elements.


.SH EXAMPLE
.nf
initial_dir = PWD;
chdir (SIPDIR + 'images');

Img = imread('tru.jpg');
Img = im2gray(Img);
xbasc()
imshow(Img);
sob = mkfilter('sobel');  // stamp effect
A = imconv(Img, sob); 
xbasc()
imshow(A, [])

chdir(initial_dir);
.fi
.SH REMARKS
The Matlab equivalent to mkfilter is "fspecial".
.SH REFERENCES
"Processamento Digital de Imagens", O. M. Filho
and H. V. Neto, Brasport -- Rio de Janeiro, 
pp. 47-56.
.LP
"Algorithms for Image Processing and Computer Vision", 
J.R. Parker, Wiley, chapter 1.
.SH AUTHORS
Ricardo Fabbri  <rfabbri@if.sc.usp.br>
.br
Jocelyn Druel   <jocelyn.druel1@libertysurf.fr>
.br
Leandro Estrozi <lfestrozi@if.sc.usp.br>
.SH AVAILABILITY
The latest version of the Scilab Image Processing toolbox can be
found at
.IP
\%http://siptoolbox.sourceforge.net
.SH "SEE ALSO"
imconv, edge
.\"
.\" SIP - Scilab Image Processing toolbox
.\" Copyright (C) 2002-2004  Ricardo Fabbri
.\"
.\" See the file COPYING for license-related issues
.\"
