.\"
.\" $Revision: 1.11 $  $Date: 2004/02/05 20:11:02 $
.\"
.\" TODO
.\"   - drawing primitives: make a section just for this
.TH MOGRIFY 1 "September 2002" "SIP Toolbox"
.SH NAME
mogrify \- filter, rotate, zoom, equalization, and MANY more.
.SH "SYNOPSIS"
.nf
[imout (,map) ] = mogrify(im, argv);
[imout (,map) ] = mogrify(imRGB, argv);
[imout (,map) ] = mogrify(index, colormap, argv);
.fi
.SH INPUT PARAMETERS
.TP
.B im
binary or grayscale image in the 0-1 range
.TP
.B imRGB
truecolor image represented as a 3D array, in the 0-1 range.
.TP
.B index
a 2D array in the 1-NC range, where NC is the number of colors.
.TP
.B colormap
an (NCx3) matrix in the 0-1 range.
.TP
.B argv
(argument vector), a string vector, row or column, containing image
processing commands. See the section "ARGV ARGUMENT" bellow for a
listing of the available options. The "EXAMPLE" bellow demonstrates
how to use this argument.

.SH OUTPUT PARAMETERS
.TP
.B imout
For truecolor images, this is a MxNx3 matrix in the 0-1 range.  
For binary images, \fIimage\fP is a MxNx1 matrix (0=black and 1=white). 
For grayscale images, this is an MxN matrix in the 0-1 range.
For indexed images, this is an MxN matrix in the 1-NC range, where NC
is the number of colors.
.TP
.B map
NCx3 matrix containing the image colormap, qhere Nc is the number of
colors. Entries range from 0 to 1.

.SH DESCRIPTION
Function \fBmogrify\fR does many image processing operations. It
is a direct C-language interface to ImageMagick, providing the same
functinality as the command-line "mogrify" utility. The difference
is that SIP's \fBmogrify\fR acts upon scilab matrices instead of
image files, and, therefore, is considerably faster. Please see
the section "ARGV ARGUMENT" bellow for details on how the parameter
\fIargv\fR is built.

.SH EXAMPLE

Please follow the TransMogrify demo:
.nf
   exec(SIPDEMO);
.fi

.SH NEWS
mogrify is now working with truecolor and paletted images.

.SH ARGV ARGUMENT
In this section, angle brackets ("<>") enclose variables and
curly brackets ("{}") enclose optional parameters. For example,
"\fB-fuzz <distance>{%}\fP" means you can use the option ['-fuzz','10']
or ['-fuzz', '2%'].

.TP
.B "-affine \fI<matrix>"\fP
\fRdrawing transform matrix

This option provides a transform matrix {sx,rx,ry,sy,tx,ty} for
use by subsequent 
\fB-draw\fP or 
\fB-transform\fP option.

.TP
.B "-antialias"
\fRremove pixel aliasing

By default antialiasing algorithms are used when drawing objects (e.g. lines)
or rendering vector formats (e.g. WMF and Postscript). Use +antialias to
disable use of antialiasing algorithms. Reasons to disable antialiasing
include avoiding increasing colors in the image, or improving rendering speed.
.\"
.TP
.B "-background \fI<color>"\fP
\fRthe background color

The color is specified using the format described in the "Color Names"
section of \fIX(1)\fP.
.\"
.TP
.B "-blur \fI<radius>x<sigma>"\fP
\fRblur the image with a Gaussian operator

Blur with the given radius and standard deviation (sigma). It is
better if the radius be greater than sigma, but the larger it is,
the slower is the processing.  If a radius equal to 0 is passed,
then mogrify uses the optimal radius.
.\"
.TP
.B "-border \fI<width>x<height>"\fP
\fRsurround the image with a border of color

See \fB-geometry\fP for details
about the geometry specification.
.\"
.TP
.B "-bordercolor \fI<color>"\fP
\fRthe border color

The color is specified using the format described in the "Color Names"
section of \fIX(1)\fP.
.\"
.TP
.B "-channel \fI<type>"\fP
\fRthe type of channel

Choose from: \fBRed\fP, \fBGreen\fP, \fBBlue\fP, 
.\"\fBOpacity\fP,
\fBCyan\fP, \fBMagenta\fP, \fBYellow\fP, or \fBBlack\fP.

Use this option to extract a particular \fIchannel\fP from the image.
.\"\fBMatte\fP,
.\"for example, is useful for extracting the opacity values from an image.
.\"
.TP
.B "-charcoal \fI<factor>"\fP
\fRsimulate a charcoal drawing
.\"
.TP
.B "-colorize \fI<value>"\fP
\fRcolorize the image with the pen color

Specify the amount of colorization as a percentage. You can apply separate
colorization values to the red, green, and blue channels of the image with
a colorization value list delineated with slashes (e.g. 0/0/50).
.\"
.TP
.B "-colorspace \fI<value>"\fP
\fRthe type of colorspace

Choices are: \fBGRAY\fP, \fBOHTA\fP, \fBRGB\fP,
\fBTransparent\fP,
\fBXYZ\fP,
\fBYCbCr\fP, \fBYIQ\fP, \fBYPbPr\fP,
\fBYUV\fP, or \fBCMYK\fP.

Color reduction, by default, takes place in the RGB color space. Empirical
evidence suggests that distances in color spaces such as YUV or YIQ correspond
to perceptual color differences more closely than do distances in RGB space.
These color spaces may give better results when color reducing an image.
Refer to quantize for more details.

The \fBTransparent\fP color space behaves uniquely in that it preserves
the matte channel of the image if it exists.

The \fB-colors\fP or \fB-monochrome\fP option is required for this
option to take effect.
.\"
.TP
.B "-contrast"
\fRenhance or reduce the image contrast

This option enhances the intensity differences between the lighter and
darker elements of the image. Use \fB-contrast\fP to enhance
the image
or \fB+contrast\fP to reduce the image contrast.
.\"
.TP
.B "-crop \fI<width>x<height>{+-}<x>{+-}<y>{%}"\fP
\fRpreferred size and location of the cropped image

See \fB-geometry\fP for details
about the geometry specification.

The width and height give the size of the image that remains after cropping,
and \fIx\fP and \fIy\fP are offsets that give the location of the top left
corner of the cropped
image with respect to the original image.  To specify the amount to be
removed, use \fB-shave\fP instead.

To specify a percentage width or height to be removed instead, append
\fB%\fP. For example
to crop the image by ten percent (five percent on each side of the image),
use \fB-crop 10%\fP.

If the \fIx\fP and \fIy\fP offsets are present, a single image is
generated, consisting of the pixels from the cropping region.
The offsets specify the location of the upper left corner of
the cropping region measured downward and rightward with respect to the
upper left corner of the image.
If the \fB-gravity\fP option is present with \fINorthEast, East,\fP
or \fISouthEast\fP
gravity, it gives the distance leftward from the right edge
of the image to the right edge of the cropping region.  Similarly, if
the \fB-gravity\fP option is present with \fISouthWest, South,\fP
or \fISouthEast\fP
gravity, the distance is measured upward between the bottom
edges.

If the \fIx\fP and \fIy\fP offsets are omitted, a set of tiles of the
specified geometry, covering the entire input image, is generated.  The
rightmost tiles and the bottom tiles are smaller if the
specified geometry extends beyond the dimensions of the input image.
.\"
.TP
.B "-cycle \fI<amount>"\fP
\fRdisplace image colormap by amount

\fIAmount\fP defines the number of positions each colormap entry is
shifted.
.\"
.TP
.B "-debug"
\fRenable debug printout
.\"
.TP
.B "-despeckle"
\fRreduce the speckles within an image
.\"
.TP
.B "-dither"
\fRapply Floyd/Steinberg error diffusion to the image

The basic strategy of dithering is to trade intensity resolution for spatial
resolution by averaging the intensities of several neighboring pixels.
Images which suffer from severe contouring when reducing colors can be
improved with this option.

The \fB-colors\fP or \fB-monochrome\fP option is required for this option
to take effect.

Use \fB+dither\fP to turn off dithering and to render PostScript without
text or graphic aliasing.
.TP
.B "-draw \fI<string>"\fP
\fRannotate an image with one or more graphic primitives

Use this option to annotate an image with one or more graphic primitives.
The primitives include shapes, text, transformations,
and pixel operations.  The shape primitives are

     point           x,y
     line            x0,y0 x1,y1
     rectangle       x0,y0 x1,y1
     roundRectangle  x0,y0 x1,y1 wc,hc
     arc             x0,y0 x1,y1 a0,a1
     ellipse         x0,y0 rx,ry a0,a1
     circle          x0,y0 x1,y1
     polyline        x0,y0  ...  xn,yn
     polygon         x0,y0  ...  xn,yn
     Bezier          x0,y0  ...  xn,yn
     path            path specification
     image           operator x0,y0 w,h filename

The text primitive is

     text            x0,y0 string

The transformation primitives are

     rotate          degrees
     translate       dx,dy
     scale           sx,sy
     skewX           degrees
     skewY           degrees

The pixel operation primitives are

     color           x0,y0 method
.\"     matte           x0,y0 method

The shape primitives are drawn in the color specified in the preceding
\fB-stroke\fP option. Except for the \fBline\fP and \fBpoint\fP
primitives, they are filled with the color specified in the preceding
\fB-fill\fP option.  For unfilled shapes, use -fill none.

\fBPoint\fP requires a single coordinate.

\fBLine\fP requires a start and end coordinate.

\fBRectangle\fP
expects an upper left and lower right coordinate.

\fBRoundRectangle\fP has the upper left and lower right coordinates
and the width and height of the corners.

\fBCircle\fP has a center coordinate and a coordinate for
the outer edge.

Use \fBArc\fP to circumscribe an arc within
a rectangle.  Arcs require a start and end point as well as the degree
of rotation (e.g. 130,30 200,100 45,90).

Use \fBEllipse\fP to draw a partial ellipse
centered at the given point with the x-axis and y-axis radius
and start and end of arc in degrees (e.g. 100,100 100,150 0,360).

Finally, \fBpolyline\fP and \fBpolygon\fP require
three or more coordinates to define its boundaries.
Coordinates are integers separated by an optional comma.  For example,
to define a circle centered at 100,100
that extends to 150,150 use:

     ['-draw'; 'circle 100,100 150,150']

\fBPaths\fP
(See Paths)
represent an outline of an object which is defined in terms of
moveto (set a new current point), lineto (draw a straight line),
curveto (draw a curve using a cubic Bezier), arc (elliptical or
circular arc) and closepath (close the current shape by drawing a line
to the last moveto) elements. Compound paths (i.e., a path with
subpaths, each consisting of a single moveto followed by one or more
line or curve operations) are possible to allow effects such as
"donut holes" in objects.

Use \fBimage\fP to composite an image with another image. Follow the
image keyword with the composite operator, image location, image size,
and filename:

     ['-draw'; 'image Over 100,100 225,225 image.jpg']

You can use 0,0 for the image size, which means to use the actual
dimensions found in the image header. Otherwise, it will
be scaled to the given dimensions.

Use \fBtext\fP to annotate an image with text. Follow the text coordinates
with a string. If the string has embedded spaces, enclose it in double
quotes. Optionally you can include the image filename, type, width, height,
or other image attribute by embedding special format character.
See \fB-comment\fP for details.

For example,

     ['-draw'; 'text 100,100 ""%wx%h""']

annotates the image with 512x480 for an image whose width
is 512 and height is 480.

If the first character of \fIstring\fP is \fI@\fP, the text is read from
a file titled by the remaining characters in the string.

\fBRotate\fP rotates subsequent shape primitives and text primitives about
the origin of the main image. If the \fB-region\fP option precedes the
\fB-draw\fP option, the origen for transformations is the upper left
corner of the region.

\fBTranslate\fP translates them.

\fBScale\fP scales them.

\fBSkewX\fP and \fBSkewY\fP skew them with respect to the origen of
the main image or the region.

The transformations modify the current affine matrix, which is initialized
from the initial affine matrix defined by the \fB-affine\fP option.
Transformations are cumulative within the \fB-draw\fP option.
The initial affine matrix is not affected; that matrix is only changed by the
appearance of another \fB-affine\fP option.  If another \fB-draw\fP
option appears, the current affine matrix is reinitialized from
the initial affine matrix.

Use \fBcolor\fP to change the color of a pixel to the fill color (see
\fB-fill\fP). Follow the pixel coordinate
with a method:

     point
     replace
     floodfill
     filltoborder
     reset

Consider the target pixel as that specified by your coordinate. The
\fBpoint\fP
method recolors the target pixel. The \fBreplace\fP method recolors any
pixel that matches the color of the target pixel.
\fBFloodfill\fP recolors
any pixel that matches the color of the target pixel and is a neighbor,
whereas \fBfilltoborder\fP recolors any neighbor pixel that is not the
border color. Finally, \fBreset\fP recolors all pixels.

.\"Use \fBmatte\fP to the change the pixel matte value to transparent. Follow
.\"the pixel coordinate with a method (see the \fBcolor\fP primitive for
.\"a description of methods). The \fBpoint\fP method changes the matte value
.\"of the target pixel. The \fBreplace\fP method changes the matte value
.\"of any pixel that matches the color of the target pixel. \fBFloodfill\fP
.\"changes the matte value of any pixel that matches the color of the target
.\"pixel and is a neighbor, whereas
.\"\fBfilltoborder\fP changes the matte
.\"value of any neighbor pixel that is not the border color (\fB-bordercolor\fP).
.\"Finally \fBreset\fP changes the matte value of all pixels.

You can set the primitive color, font, and font bounding box
color with
\fB-fill\fP, \fB-font\fP, and \fB-box\fP respectively. Options
are processed in the \fBargv\fP order so be sure to use these
options \fIbefore\fP the \fB-draw\fP option.
.\"
.TP
.B "-edge \fI<radius>"\fP
\fRdetect edges within an image
.TP
.B "-emboss"
\fRemboss an image
.TP
.B "-encoding \fI<type>"\fP
\fRspecify the text encoding

Choose from \fIAdobeCustom, AdobeExpert, AdobeStandard, AppleRoman,
BIG5, GB2312, Latin 2, None, SJIScode, Symbol, Unicode, Wansung.\fP
.\"
.TP
.B "-enhance"
\fRapply a digital filter to enhance a noisy image
.TP
.B "-equalize"
\fRperform histogram equalization to the image
.TP
.B "-fill \fI<color>"\fP
\fRcolor to use when filling a graphic primitive

The color is specified using the format described in the "Color Names"
section of \fIX(1)\fP.

See \fB-draw\fP for further
details.

.TP
.B "-filter \fI<type>"\fP
\fRuse this type of filter when resizing an image

Use this option to affect the resizing operation of an image (see
\fB-geometry\fP).
Choose from these filters:

     Point
     Box
     Triangle
     Hermite
     Hanning
     Hamming
     Blackman
     Gaussian
     Quadratic
     Cubic
     Catrom
     Mitchell
     Lanczos
     Bessel
     Sinc

The default filter is \fBLanczos\fP

.B "-flip"
\fRcreate a "mirror image"

reflect the scanlines in the vertical direction.
.\"
.TP
.B "-flop"
\fRcreate a "mirror image"

reflect the scanlines in the horizontal direction.
.\"
.TP
.B "-font \fI<name>"\fP
\fRuse this font when annotating the image with text

You can tag a font to specify whether it is a PostScript, TrueType, or OPTION1
font.  For example, Arial.ttf is a TrueType font, ps:helvetica
is PostScript, and x:fixed is OPTION1.
.\"
.TP
.B "-foreground \fI<color>"\fP
\fRdefine the foreground color

The color is specified using the format described in the "Color Names"
section of \fIX(1)\fP.
.TP
.B "-frame \fI<width>x<height>+<outer bevel width>+<inner bevel width>"\fP
\fRsurround the image with an ornamental border

See \fB-geometry\fP for details
about the geometry specification.
The \fB-frame\fP option is not affected by the \fB-gravity\fP option.

The color of the border is specified with the
\fB-mattecolor\fP command
line option.
.\"
.TP
.B "-frame"
\fRinclude the X window frame in the imported image
.TP
.B "-fuzz \fI<distance>{%}"\fP
\fRcolors within this distance are considered equal

A number of algorithms search for a target color. By default the color
must be exact. Use this option to match colors that are close to the target
color in RGB space. For example, if you want to automatically trim the
edges of an image with \fB-trim\fP but the image was scanned and the
target background color may differ by a small amount. This option can account
for these differences.

The \fIdistance\fP can be in absolute intensity units or, by appending
\fI"%"\fP, as a percentage of the maximum possible intensity.
.\"
.TP
.B "-gamma \fI<value>"\fP
\fRlevel of gamma correction

The same color image displayed on two different workstations may look different
due to differences in the display monitor. Use gamma correction to adjust
for this color difference. Reasonable values extend from \fB0.8\fP to
\fB2.3\fP.

You can apply separate gamma values to the red, green, and blue channels
of the image with a gamma value list delineated with slashes
(e.g., \fB1.7\fP/\fB2.3\fP/\fB1.2\fP).

.\"Use \fB+gamma\fP \fIvalue\fP
.\"to set the image gamma level without actually adjusting
.\"the image pixels. This option is useful if the image is of a known gamma
.\"but not set as an image attribute (e.g. PNG images).
.\"
.TP
.B "-Gaussian \fI<radius>x<sigma>"\fP
\fRblur the image with a Gaussian operator

Use the given radius and standard deviation (sigma).
.\"
.TP
.B "-geometry \fI<width>x<height>{+-}<x>{+-}<y>{%}{@} {!}{<}{>}"\fP
\fRpreferred size and location of the Image window.

By default, the window size is the image
size and the location is chosen by you when it is mapped.

By default, the width and height are maximum values. That is, the image
is expanded or contracted to fit the width and height value while maintaining
the aspect ratio of the image. \fIAppend an exclamation point to the geometry
to force the image size to exactly the size you specify\fP. For example,
if you specify 640x480! the image width is set to 640 pixels and
height to 480.

If only the width is specified, the width assumes the
value and the height is chosen to maintain the aspect ratio of the image.
Similarly, if only the height is specified (e.g., -geometry x256),
the width is chosen to maintain the aspect ratio.

To specify a percentage width or height instead, append %. The image size
is multiplied by the width and height percentages to obtain the final image
dimensions. To increase the size of an image, use a value greater than
100 (e.g. 125%). To decrease an image's size, use a percentage less than
100.

Use @ to specify the maximum area in pixels of an image.

Use > to change the dimensions of the image \fIonly\fP if
its width or height exceeds the geometry specification. < resizes
the image \fIonly\fP if both of its dimensions are less than the geometry
specification. For Example,
if you specify '640x480>' and the image size is 256x256, the image
size does not change. However, if the image is 512x512 or 1024x1024, it is
resized to 480x480.  Enclose the geometry specification in quotation marks to
prevent the < or > from being interpreted by your shell
as a file redirection.

\fB-geometry\fP is synonymous with \fB-resize\fP and
specifies the size of the output image.  The offsets, if present, are ignored.

.TP
.B "-gravity \fI<type>"\fP
\fRdirection primitive  gravitates to when annotating the image.

Choices are: NorthWest, North,
NorthEast, West, Center, East, SouthWest, South, SouthEast.

The direction you choose specifies where to position the text or other
graphic primitive when annotating
the image. For example \fICenter\fP gravity forces the text to be centered
within the image. By default, the image gravity is \fINorthWest\fP.
See \fB-draw\fP for more details about graphic primitives.

The \fB-gravity\fP option is also used in concert with the \fB-geometry\fP
option and other options that take \fB<geometry>\fP as a parameter, such
as the \fB-crop\fP option.  See \fB-geometry\fP for details of how the
\fB-gravity\fP option interacts with the
\fB<x>\fP and \fB<y>\fP parameters of a geometry
specification.
.\"
.TP
.B "-implode \fI<factor>"\fP
\fRimplode image pixels about the center. It is a real number.
.\"
.TP
.B "-interlace \fI<type>"\fP
\fRthe type of interlacing scheme

Choices are: \fBNone, Line, Plane,\fP
or \fBPartition\fP. The default is \fBNone\fP.

This option is used to specify the type of interlacing scheme for raw image
formats such as \fBRGB\fP or \fBYUV\fP.

\fBNone\fP means do not interlace
(RGBRGBRGBRGBRGBRGB...),

\fBLine\fP uses scanline interlacing
(RRR...GGG...BBB...RRR...GGG...BBB...),
and

\fBPlane\fP uses plane interlacing (RRRRRR...GGGGGG...BBBBBB...).

\fBPartition\fP
is like plane except the different planes are saved to individual files
(e.g. image.R, image.G, and image.B).

Use \fBLine\fP or \fBPlane\fP to create an
\fBinterlaced PNG\fP or \fB GIF\fP or
\fBprogressive JPEG\fP image.
.\"
.TP
.B "-lat \fI<radius>x<sigma>{+-}<offset>{%}"\fP
\fRperform local adaptive thresholding

Perform local adaptive thresholding using the specified radius, sigma,
and offset.  The offset is a distance in sample space from the mean,
as an absolute integer ranging from 0 to the maximum sample value or
as a percentage.
For reasonable results, radius should be larger than sigma.  Use a radius
of 0 to have the method select a suitable radius.
.\"
.TP
.B "-level \fI<value>"\fP
\fRadjust the level of image contrast

Give three point values delineated with commas: black, mid, and white
(e.g. 10,1.0,65000).  The white and black points range from 0 to MaxRGB
and mid ranges from 0 to 10.
.TP
.B "-linewidth"
\fRthe line width for subsequent draw operations
.\".TP
.\".B "-map \fI<filename>"\fP
.\"\fRchoose a particular set of colors from this image
.\"
.\"
.\"By default, color reduction chooses an optimal set of colors that best
.\"represent the original image. Alternatively, you can choose a particular
.\"set of colors from an image file with this option.
.\"
.\"Use
.\"\fB+map\fP to reduce
.\"all images in the image sequence that follows to a single optimal set of colors
.\"that best represent all the images.  The sequence of images
.\"is terminated by the appearance of any option.
.\"If the \fB+map\fP
.\"option appears after all of the input images, all images are mapped.
.\"
.TP
.B "-mask \fI<filename>"\fP
\fRSpecify a clipping mask

The image read from the file is used as a clipping mask.  It must have
the same dimensions as the image being masked.

If the mask image contains an opacity channel, the opacity of each pixel is
used to define the mask.  Otherwise, the intensity (gray level) of each
pixel is used.

Use \fB+mask\fP to remove the clipping mask.

It is not necessary to use \fB-clip\fP to activate the mask; \fB-clip\fP
is implied by \fB-mask\fP.
.\".TP
.\".B "-matte"
.\"\fRstore matte channel if the image has one
.\"
.\"If the image does not have a matte channel, create an opaque one.
.\"
.\"Use \fB+matte\fP to ignore the matte channel and to avoid writing a
.\"matte channel in the output file.

.\".TP
.\".B "-mattecolor \fI<color>"\fP
.\"\fRspecify the color to be used with the \fB-frame\fP option
.\"
.\"The color is specified using the format described in the "Color Names"
.\"section of \fIX(1)\fP.
.\"
.TP
.B "-median \fI<radius>"\fP
\fRapply a median filter to the image
.\"
.TP
.B "-monochrome"
\fRtransform the image to black and white
.\"
.TP
.B "-negate"
\fRreplace every pixel with its complementary color

The red, green, and blue intensities of an image are negated.
White becomes black,
yellow becomes blue, etc.
Use \fB+negate\fP
to only negate the grayscale pixels of the image.
.\"
.TP
.B "-noise \fI<radius|type>"\fP
\fRadd or reduce noise in an image

The principal function of noise peak elimination filter is to smooth the
objects within an image without losing edge information and without creating
undesired structures. The central idea of the algorithm is to replace a
pixel with its next neighbor in value within a pixel window, if this pixel
has been found to be noise. A pixel is defined as noise if and only if
this pixel is a maximum or minimum within the pixel window.

Use \fBradius\fP to specify the width of the neighborhood.

Use \fB+noise\fP followed by a noise type to add noise to an image. Choose
from these noise types:

     Uniform
     Gaussian
     Multiplicative
     Impulse
     Laplacian
     Poisson
.\"
.TP
.B "-normalize"
\fRtransform image to span the full range of color values

This is a contrast enhancement technique.

.TP
.B "-opaque \fI<color>"\fP
\fRchange this color to the pen color within the image

The color is specified using the format described in the "Color Names"
section of \fIX(1)\fP.

.\"See \fB-fill\fP for more details.

.TP
.B "-paint \fI<radius>"\fP
\fRsimulate an oil painting

Each pixel is replaced by the most frequent color in a circular neighborhood
whose width is specified with \fIradius\fP.
.\"
.TP
.B "-raise \fI<width>x<height>"\fP
\fRlighten or darken image edges

This will create a 3-D effect.
See \fB-geometry\fP for details
details about the geometry specification.
Offsets are not used.

Use \fB-raise\fP to create a raised effect, otherwise use \fB+raise\fP.
.\"
.TP
.B "-region \fI<width>x<height>{+-}<x>{+-}<y>"\fP
\fRapply options to a portion of the image

The \fIx\fP and \fIy\fP offsets are treated in the same manner as in \fB-crop\fP.
.\"
.TP
.B "-resize \fI<width>x<height>{%}{@}{!}{<}{>}"\fP
\fRresize an image

This is an alias for the \fB-geometry\fP option and it behaves in the
same manner. If the \fB-filter\fP option precedes the \fB-resize\fP
option, the specified filter is used.

There are some exceptions:

When used as a \fIcomposite\fP option, \fB-resize\fP conveys the preferred
size of the output image, while \fB-geometry\fP conveys
the size and placement of the \fIcomposite image\fP within the main
image.

When used as a \fImontage\fP option, \fB-resize\fP conveys the preferred
size of the montage, while \fB-geometry\fP conveys
information about the tiles.
.\"
.TP
.B "-roll \fI{+-}<x>{+-}<y>"\fP
\fRroll an image vertically or horizontally

See \fB-geometry\fP for details
the geometry specification.
The \fIx\fP and \fIy\fP offsets are not affected
by the \fB-gravity\fP option.

A negative \fIx\fP  offset rolls the image left-to-right. A negative \fIy\fP
offset rolls the image top-to-bottom.
.\"
.TP
.B "-rotate \fI<degrees>{<}{>}"\fP
\fRapply Paeth image rotation to the image

Use > to rotate the image only if its width exceeds the height.
< rotates the image \fIonly\fP if its width is less than the
height. For example, if you specify -rotate "-90>" and the image
size is 480x640, the image is not rotated.  However, if the
image is 640x480, it is rotated by -90 degrees.  If you use > or
<, enclose it in quotation marks to prevent it from being
misinterpreted as a file redirection.


Empty triangles left over from rotating the image are filled with the color
defined as \fBbackground\fP (class \fBbackgroundColor\fP). See \fIX(1)\fP
for details.
.\"
.TP
.B "-sample \fI<geometry>"\fP
\fRscale image with pixel sampling

See \fB-geometry\fP for details about
the geometry specification.
\fB-sample\fP ignores the \fB-filter\fP selection if the \fB-filter\fP option
is present.  Offsets, if present in the geometry string, are ignored, and
the \fB-gravity\fP option has no effect.
.\"
.TP
.B "-sampling_factor \fI<horizontal_factor>x<vertical_factor>"\fP
\fRsampling factors used by JPEG or MPEG-2 encoder and YUV decoder/encoder.

This option specifies the sampling factors to be used by the JPEG encoder for
chroma downsampling.  If this option is omitted, the JPEG library
will use its own default values.  When reading or writing the YUV format
and when writing the M2V (MPEG-2) format, use
\fB-sampling_factor 2x1\fP to specify the 4:2:2 downsampling method.
.\"
.TP
.B "-scale \fI<geometry>"\fP
\fRscale the image.

See \fB-geometry\fP for details about
the geometry specification.  \fB-scale\fP uses a simpler, faster algorithm,
and it ignores the \fB-filter\fP selection if the \fB-filter\fP option
is present.  Offsets, if present in the geometry string, are ignored, and
the \fB-gravity\fP option has no effect.
.\"
.TP
.B "-seed \fI<value>"\fP
\fRpseudo-random number generator seed value
.\"
.TP
.B "-segment \fI<cluster threshold>x<smoothing threshold>"\fP
\fRsegment an image

Segment an image by analyzing the histograms of the color components and
identifying units that are homogeneous with the fuzzy c-means technique.

Specify \fIcluster threshold\fP as the number of pixels in each cluster
must exceed the the cluster threshold to be considered valid. \fISmoothing
threshold\fP eliminates noise in the second derivative of the histogram.
As the value is increased, you can expect a smoother second derivative.
The default is 1.5. See
"Image Segmentation", below,
for details.
.\"
.TP
.B "-shade \fI<azimuth>x<elevation>"\fP
\fRshade the image using a distant light source

Specify \fIazimuth\fP and \fIelevation\fP as the position of the light
source. Use \fB+shade\fP to return the shading results as a grayscale
image.
.\"
.TP
.B "-sharpen \fI<radius>x<sigma>"\fP
\fRsharpen the image

Use a Gaussian operator of the given radius and
standard deviation (sigma).
.\"
.TP
.B "-shave \fI<width>x<height>"\fP
\fRshave pixels from the image edges

Specify the width of the region to be removed from both
sides of the image and the height of the regions to be removed from
top and bottom.
.\"
.TP
.B "-shear \fI<x degrees>x<y degrees>"\fP
\fRshear the image along the X or Y axis

Use the specified positive or negative shear angle.

Shearing slides one edge of an image along the X or Y axis, creating a
parallelogram. An X direction shear slides an edge along the X axis, while
a Y direction shear slides an edge along the Y axis. The amount of the
shear is controlled by a shear angle. For X direction shears, \fIx degrees\fP
is measured relative to the Y axis, and similarly, for Y direction shears
\fIy
degrees\fP is measured relative to the X axis.

Empty triangles left over from shearing the image are filled with the color
defined as \fBbackground\fP (class \fBbackgroundColor\fP). See \fIX(1)\fP
for details.
.\"
.TP
.B "-solarize \fI<factor>"\fP
\fRnegate all pixels above the threshold level

Specify \fIfactor\fP as the
percent threshold of the intensity (0 - 99.9%).

This option produces a \fIsolarization\fP effect seen when exposing a
photographic film to light during the development process.
.\"
.TP
.B "-spread \fI<amount>"\fP
\fRdisplace image pixels by a random amount

\fIAmount\fP defines the size of the neighborhood around each pixel to
choose a candidate pixel to swap.
.\"
.TP
.B "-stroke \fI<color>"\fP
\fRcolor to use when stroking a graphic primitive

The color is specified using the format described in the "Color Names"
section of \fIX(1)\fP.

See \fB-draw\fP for further
details.

.TP
.B "-strokewidth \fI<value>"\fP
\fRset the stroke width

See \fB-draw\fP for further details.
.\"
.TP
.B "-swirl \fI<degrees>"\fP
\fRswirl image pixels about the center

\fIDegrees\fP defines the tightness of the swirl.
.\"
.\" FILENAME OPTION
.\".TP
.\".B "-texture \fI<filename>"\fP
.\"\fRname of texture to tile onto the image background
.\"
.TP
.B "-threshold \fI<value>"\fP
\fRthreshold the image
.\"
Create a bi-level image such that any pixel intensity that is equal or
exceeds the threshold is reassigned the maximum intensity otherwise the
minimum intensity.
.\" FILENAME OPTION
.\".TP
.\".B "-tile \fI<filename>"\fP
.\"\fRtile image when filling a graphic primitive
.TP
.B "-tile \fI<geometry>"\fP
\fRlayout of images [\fImontage\fP]
.TP
.B "-transform"
\fRtransform the image

This option applies the transformation matrix from a previous
\fB-affine\fP option.

    mogrify(img, '-affine 2,2,-2,2,0,0 -transform bird.ppm');
.\"
.\".TP
.\".B "-transparent \fI<color>"\fP
.\"\fRmake this color transparent within the image
.\"
.\"The color is specified using the format described in the "Color Names"
.\"section of \fIX(1)\fP.
.\"
.TP
.B "-treedepth \fI<value>"\fP
\fRtree depth for the color reduction algorithm

Normally, this integer value is zero or one. A zero or one tells display
to choose an optimal tree depth for the color reduction algorithm

An optimal depth generally allows the best representation of the source
image with the fastest computational speed and the least amount of memory.
However, the default depth is inappropriate for some images. To assure
the best representation, try values between 2 and 8 for this parameter.
Refer to
quantize for more details.

The \fB-colors\fP or \fB-monochrome\fP option is required for this option
to take effect.
.\"
.TP
.B "-trim"
\fRtrim an image

This option removes any edges that are exactly the same color as the
corner pixels.  Use \fB-fuzz\fP to make \fB-trim\fP remove edges that
are nearly the same color as the corner pixels.
.\"
.\".TP
.\".B "-type \fI<type>"\fP
.\"\fRthe image type
.\"
.\"Choose from:
.\"\fBBilevel\fP, \fBGrayscale\fP, \fBPalette\fP,
.\"\fBPaletteMatte\fP, \fBTrueColor\fP, \fBTrueColorMatte\fP,
.\"\fBColorSeparation\fP, \fBColorSeparationMatte\fP, or \fBOptimize\fP.
.\"
.\"Normally, when a format supports different subformats such as grayscale
.\"and truecolor, the encoder will try to choose an efficient subformat.
.\"The \fB-type\fP option can be used to overrride this behavior.  For
.\"example, to prevent a JPEG from being written in grayscale format even
.\"though only gray pixels are present, use
.\"
.\"    convert bird.pgm -type TrueColor bird.jpg
.\"
.\"Similarly, using -type TrueColorMatte will force the encoder
.\"to write an alpha channel even though the image is opaque, if the
.\"output format supports transparency.
.\"
.TP
.B "-unsharp \fI<radius>x<sigma>"\fP
\fRsharpen the image with an unsharp mask operator

Use the given radius and standard deviation (sigma).

.B "-wave \fI<amplitude>x<wavelength>"\fP
\fRalter an image along a sine wave

Specify \fIamplitude\fP and \fIwavelength\fP
of the wave.

.SH IMAGE SEGMENTATION

Use \fB-segment\fP to segment an image by analyzing the histograms of
the color components and identifying units that are homogeneous with the
fuzzy c-means technique. The scale-space filter analyzes the histograms
of the three color components of the image and identifies a set of classes.
The extents of each class is used to coarsely segment the image with thresholding.
The color associated with each class is determined by the mean color of
all pixels within the extents of a particular class. Finally, any unclassified
pixels are assigned to the closest class with the fuzzy c-means technique.

The fuzzy c-Means algorithm can be summarized as follows:
    
Build a histogram, one for each color component of the image.
    
For each histogram, successively apply the scale-space filter and build
an interval tree of zero crossings in the second derivative at each scale.
Analyze this scale-space "fingerprint" to determine which peaks or valleys
in the histogram are most predominant.
    
The fingerprint defines intervals on the axis of the histogram. Each interval
contains either a minima or a maxima in the original signal. If each color
component lies within the maxima interval, that pixel is considered "classified"
and is assigned an unique class number.
    
Any pixel that fails to be classified in the above thresholding pass is
classified using the fuzzy c-Means technique. It is assigned to one of
the classes discovered in the histogram analysis phase.

The fuzzy c-Means technique attempts to cluster a pixel by finding the
local minima of the generalized within group sum of squared error objective
function. A pixel is assigned to the closest class of which the fuzzy membership
has a maximum value.

For additional information see:
\fIYoung Won Lim, Sang Uk Lee\fP, ``\fBOn The Color Image Segmentation
Algorithm Based on the Thresholding and the Fuzzy c-Means Techniques\fP'',
Pattern Recognition, Volume 23, Number 9, pages 935-952, 1990.

.SH AUTHORS
Ricardo Fabbri <rfabbri@if.sc.usp.br>
.SH AVAILABILITY
The latest version of the Scilab Image Processing toolbox can be
found at
.IP
\%http://siptoolbox.sourceforge.net
.SH "SEE ALSO"
imread, imwrite, imfinfo
.\"
.\" SIP - Scilab Image Processing toolbox
.\" Copyright (C) 2002-2004  Ricardo Fabbri
.\"
.\" See the file COPYING for license-related issues
.\"
