.\"
.\" $Revision: 1.2 $  $Date: 2004/02/05 09:24:16 $
.\"
.TH PIFILTER "December 2003" "SIP Toolbox"
.SH NAME
pifilter \- pi filter for phased images
.SH "SYNOPSIS"
.nf
filtered_image = pifilter(image[,filter_name])
.fi
.SH PARAMETERS
.TP
.B image
A gray image (normally a phased image).
.TP
.B filter_name
A low-pass filter. It can be
\'mean' or 'low-pass' (see mkfilter).
Default is 'mean'.

.SH DESCRIPTION
Filters a phased image before unwrapping it.
The purpose is to keep the phase jumps sharp: a convolution by a 
low-pass kernel would be catastrophic, because it would smooth 
these jumps, causing the demodulation algorithm to fail.

Principle:
.br
1) We calculate the sinus and cosinus of the phase
.br
2) We apply a convolution filtering on each component
.br
3) We get the phase again with an atan

This function uses the mkfilter and imconv functions.
Reasonable kernels are: 'low-pass' and 'mean'. A high-pass filter
would make no sense as it would burst noise !

You can use pifilter for ordinary grayscale images to smooth them
without loosing the edges. This filter is similar to the median
filter, but will leave edges even stronger. However, the noise will
more often not be removed; just attenuated.


.SH EXAMPLE
.nf
a=gray_imread(SIPDIR+'images/photonics/pyramide_noisy.jpg');
xset("window",0);xbasc();
imshow(a);
improfile(a);//to visualise profiles
b=pifilter(a);
xset("window",1);xbasc();
imshow(b);
improfile(b);//jumps are still well visible and other parts are smoothed

.fi
.SH REFERENCES:
"Techniques automatiques de raccordement de phase" by David Venet
.br
Ecole Federale de Lausanne (1995-96)

.SH AUTHORS
Jocelyn DRUEL <jocelyn.druel1@libertysurf.fr>

.SH AVAILABILITY
The latest version of the Scilab Image Processing toolbox can be
found at
.IP
\%http://siptoolbox.sourceforge.net
.SH "SEE ALSO"
unwrapl,unwrapp,mkfilter,imconv
.\"
.\" SIP - Scilab Image Processing toolbox
.\" Copyright (C) 2002-2004  Ricardo Fabbri
.\"
.\" See the file COPYING for license-related issues
.\"
