.\"
.\" $Revision: 1.9 $ $Date: 2004/02/03 08:45:50 $
.\"
.TH UNFOLLOW 1 "January 2002" "SIP Toolbox"
.SH NAME
unfollow \- converts a parametric contour into a binary image
.SH "SYNOPSIS"
.nf
Img = unfollow(x,y,dims)
.fi
.SH PARAMETERS
.TP
.B x and y
vectors, storing the parametrized contour. They are
truncated before calculation.
.TP
.B dims
vector [row, column] storing the dimensions of the output
Image. This has to be consistent with the size of
the resulting contour.
.TP
.B Img
binary array,  1 for object and 0 for background (double
precision)
.SH DESCRIPTION
Function \fBunfollow\fR plots a contour from its 
parametric representation into a binary image. 
This operation is the reverse of the \fIfollow\fR
function.
.LP
\fIx\fR and \fIy\fR both store the parametrized contour. That
is, (x(i),y(i)) is a point of the contour, where the coordinate
system is assumed as starting from bottom-left corner (0,0) to
uper-right corner of the image. To get (x,y) coordinates from 
(row,col) matrix coordinates, use the transformation below:
.IP
      x = col - 1
      y = dims(1) - row
.SH EXAMPLE
.nf
initial_dir = PWD;
chdir (SIPDIR + 'images');

Img = imread('star.bmp');
xset('window',0);
xbasc()
imshow(Img,2);
[x,y] = follow(Img);
xbasc()
xsm = gsm(x,15);
ysm = gsm(y,15);
Img2=unfollow(xsm,ysm,size(Img));
xbasc()
imshow(Img2,2);

chdir(initial_dir);
.fi
.SH "BUGS AND SHORTCOMINGS"
Images are stored in double precision matrices. Hopefully, the next release
will make usage of integer types.
.SH AUTHORS
Ricardo Fabbri <rfabbri@if.sc.usp.br>
.SH AVAILABILITY
The latest version of the Scilab Image Processing toolbox can be
found at
.IP
\%http://siptoolbox.sourceforge.net
.SH "SEE ALSO"
follow, bwborder, gsm, curvature  
.\"
.\" SIP - Scilab Image Processing toolbox
.\" Copyright (C) 2002-2004  Ricardo Fabbri
.\"
.\" See the file COPYING for license-related issues
.\"
