/*
 * -------------------------------------------------------------------------
 * SIP - Scilab Image Processing toolbox
 * Copyright (C) 2002-2004  Ricardo Fabbri
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * -------------------------------------------------------------------------
 */ 
  

#include <stack-c.h>
#include <stdio.h>
#include <string.h>
#include <animal/animal.h>
#include "sip_common.h"


/*----------------------------------------------------------
 * [img]=drawline(img,xy)
 * - xy is a nx2 vector of n 2D (row,col) coordinates 
 *
 * TODO
 * - work with integers
 * - interface must be similar to matlab 
 *----------------------------------------------------------*/
SipExport int 
drawline_int(char *fname)
{
   /* Interface variables */ 
   int   r1, c1, p1,  
         r2, c2, p2,  
         ro, co,
         i,
         minlhs=1, maxlhs=1, minrhs=2, maxrhs=3;
   Img *im;
   double *po;
   bool stat;

   CheckRhs(minrhs,maxrhs);
   CheckLhs(minlhs,maxlhs);


   GetRhsVar(1, "d", &r1, &c1, &p1);  // img 
   GetRhsVar(2, "d", &r2, &c2, &p2);  // xy
   if (c2 != 2)
      sip_error("drawline: second arg. must have 2 cols");
   if (r2 < 2)
      sip_error("drawline: second arg. must have 2 or more rows");

   im=new_img(c1, r1);
   sci_2D_double_matrix_to_animal(p1,r1,c1,im,pixval,1);
    
   for (i=p2; i < p2+r2-1; ++i)
      imdrawline(im, PROUND(unsigned,*stk(i)-1), 
                     PROUND(unsigned,c1 - *stk(i+r2)),
                     PROUND(unsigned,*stk(i+1)-1), 
                     PROUND(unsigned,c1 - *stk(i+1+r2)));

   stat = animal_grayscale_image_to_double_array(fname, im, &po);
   if (!stat) return false;
   imfree(&im);

   ro=r1; co=c1;
   CreateVarFromPtr(3, "d", &ro, &co, &po);
   /*  Return variables  */
   LhsVar(1) = 3;
   free(po);
   return true;
}
