/*
 * -------------------------------------------------------------------------
 * SIP - Scilab Image Processing toolbox
 * Copyright (C) 2002-2004  Ricardo Fabbri
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 * -------------------------------------------------------------------------
 */ 

#include "sip_common.h"
#include <string.h>

bool
sci_2D_double_matrix_to_magick(char *fname, int p, int r, int c, Image *image, PixelPacket **ppix)
{

   PixelPacket  *pix;
   ExceptionInfo  exception;
   unsigned i,j;

   
   image->rows=r; image->columns=c;
   pix = SetImagePixels(image, 0, 0, (unsigned long)c, (unsigned long)r);
   if(pix == (PixelPacket *) NULL)
      SIP_MAGICK_ERROR;

   ppix = &pix;

   image->storage_class=DirectClass;
   SetImageType(image,GrayscaleType);

   for (i=0; i < image->rows; i++)
      for (j=0; j < image->columns; j++) {
         IndexImgByRow(pix,i,j).red   = 
            PROUND(Quantum, IndexImgByCol(stk(p),i,j)*MaxRGB);
         IndexImgByRow(pix,i,j).green = 
            PROUND(Quantum, IndexImgByCol(stk(p),i,j)*MaxRGB);
         IndexImgByRow(pix,i,j).blue  = 
            PROUND(Quantum, IndexImgByCol(stk(p),i,j)*MaxRGB);
      }

   if(!SyncImagePixels(image))
      SIP_MAGICK_ERROR;

   return true;
}

bool
sci_3D_double_hypermat_to_magick(char *fname, int nv, HyperMat *Img, Image *image, PixelPacket **ppix)
{
   HyperMat Im;
   PixelPacket   *pix;
   ExceptionInfo  exception;
   unsigned i,j;

   GetRhsHMat(nv,Img);
   Im = *Img;
   if (Im.dimsize != 3)
      sip_error("argument 1 is not a 3D hypermatrix")
   else if (Im.dims[2] != 3)
      sip_error("argument 1 is not a M x N x 3 hypermatrix")

   image->rows=Im.dims[0];
   image->columns=Im.dims[1];
   image->storage_class=DirectClass;
   
   pix = SetImagePixels(image, 0, 0, image->columns, image->rows);
   if(pix == (PixelPacket *) NULL) 
      SIP_MAGICK_ERROR;

   *ppix = pix;
   for (i=0; i< image->rows; i++)
      for (j=0; j< image->columns; j++) {
         IndexImgByRow(pix,i,j).red   = 
            PROUND(Quantum, IndexImg3d(Im.R, i,j,0)*MaxRGB);
         IndexImgByRow(pix,i,j).green = 
            PROUND(Quantum, IndexImg3d(Im.R, i,j,1)*MaxRGB);
         IndexImgByRow(pix,i,j).blue  = 
            PROUND(Quantum, IndexImg3d(Im.R, i,j,2)*MaxRGB);
      }

   if(!SyncImagePixels(image))
      SIP_MAGICK_ERROR;

   SetImageType(image,TrueColorType);

   return true;
}

bool
sci_index_map_to_magick(char *fname, int nv, Image *image, PixelPacket **ppix)
{
   PixelPacket   *pix;
   IndexPacket   *index;
   ExceptionInfo  exception;
   unsigned i,j,imgsize;
   int rim, cim, pim, rmap, cmap, pmap;

   GetRhsVar(nv, "d", &rim, &cim, &pim);
   GetRhsVar(nv+1, "d", &rmap, &cmap, &pmap);
   if(cmap != 3)
     sip_error("colormap array must have exactly 3 columns");

   image->rows=rim;
   image->columns=cim;
   imgsize=rim*cim;
   image->storage_class=PseudoClass;
   image->colors=rmap;
   image->colormap=NULL;

   pix = SetImagePixels(image, 0, 0, image->columns, image->rows);
   if(pix == (PixelPacket *) NULL)
      SIP_MAGICK_ERROR;

   *ppix = pix;

   if((index = GetIndexes(image)) == (IndexPacket *) NULL)
      SIP_MAGICK_ERROR;

   if(AllocateImageColormap(image,image->colors) == 0)
      SIP_MAGICK_ERROR;
   
   for (i=0; i<image->colors; i++) {
      image->colormap[i].red   = 
         PROUND(Quantum, stk(pmap)[i] * MaxRGB);
      image->colormap[i].green = 
         PROUND(Quantum, stk(pmap)[i+image->colors] * MaxRGB);
      image->colormap[i].blue  = 
         PROUND(Quantum, stk(pmap)[i+2*(image->colors)] * MaxRGB);
   } 
   for (i=0; i< image->rows; i++)
      for (j=0; j< image->columns; j++) 
         IndexImgByRow(index,i,j) = PROUND(Quantum, IndexImgByCol(stk(pim),i,j))-1;
      

   SyncImage(image);

   SetImageType(image,PaletteType);
   return true;
}

/*-----------------------------------------
 * Cre_hmat:                                                 
 * Creates a Scilab hypermatrix (mlist)
 * from a hypermatrix structure 
 *-----------------------------------------*/
bool 
sip_cre_hmat(int pos, HyperMat *H)
{
  static char *Str[]= { "hm","dims","entries"}; int m1=1,n1=3;
  int mL=3,nL=1,lL, un=1;
  CreateVar(pos,"m", &mL, &nL, &lL);
  CreateListVarFromPtr(pos,1,"S", &m1, &n1, Str);
  CreateListVarFromPtr(pos,2,"i",&un, &H->dimsize, &H->dims);
  CreateListCVarFromPtr(pos,3,"d", &H->it,&H->size,&un ,&H->R,&H->I);
  return true;
}

/*----------------------------------------------------
 * get_rhs_hmat:                                                
 *    Creates a hypermatrix structure from a Scilab
 *    hypermatrix (mlist)   
 *----------------------------------------------------*/
bool
sip_get_rhs_hmat(int pos, HyperMat *H) 
{
  char **Str2;
  int m,n,l,m1,n1,m2,n2,l2,m3,n3,l3,it3,lc3;
  GetRhsVar(pos,"m",&m,&n,&l);
  CheckLength(pos,m,3);
  GetListRhsVar(pos,1,"S",&m1,&n1,&Str2);
  if ( strcmp(Str2[0],"hm") != 0) {
      Scierror(999,"Argument %d is not an hypermatrix\r\n",pos);
      return false;
  }
  GetListRhsVar(pos,2,"i",&m2,&n2,&l2);
  GetListRhsCVar(pos,3,"d",&it3,&m3,&n3,&l3,&lc3);
  H->dims = istk(l2);
  H->dimsize = m2*n2;
  H->size = m3*n3;
  H->R = stk(l3);
  H->I = (it3==1) ? stk(lc3): NULL;
  H->it= it3;
  FreeRhsSVar(Str2);
  return true;
}

bool
magick_binary_image_to_double_array(char *fname, PixelPacket *pix, double **dbl_array, int rows, int cols)
{
   int i,j;
   double *imptr;

#ifndef NDEBUG
         sciprint("Binary Image\n\r");
#endif

   imptr = (double *)calloc(rows*cols, sizeof(double));
   if (!imptr)
     sip_error("unable to alloc memory\n");
   for (i=0; i < rows; i++) 
      for (j=0; j < cols; j++) 
         RCbyC(imptr,i,j,rows) = RCbyR(pix,i,j,cols).red / MaxRGB;
   *dbl_array = imptr;
   return true;
}

bool
magick_grayscale_image_to_double_array(char *fname, PixelPacket *pix, double **dbl_array, int rows, int cols)
{
   int i,j;
   double *imptr, factor = 1.0 / MaxRGB;

#ifndef NDEBUG
         sciprint("Grayscale Image\n\r");
#endif

   imptr = (double *)calloc(rows*cols, sizeof(double));
   if (!imptr)
     sip_error("unable to alloc memory\n");
   for (i=0; i < rows; i++) 
      for (j=0; j < cols; j++) 
         RCbyC(imptr,i,j,rows) = RCbyR(pix,i,j,cols).red * factor;
   *dbl_array = imptr;
   return true;
}

bool
magick_truecolor_image_to_double_hypermat(char *fname,PixelPacket *pix,HyperMat *H, int rows, int cols)
{
   int i,j;
   double factor = 1.0 / MaxRGB;

#ifndef NDEBUG
   sciprint("Truecolor Image\n\r");
#endif

   H->dimsize = 3;  /* R, G and B arrays */
   H->dims = (int *)calloc(H->dimsize, sizeof(int)); 
   if (!H->dims)
      sip_error("unable to alloc memory for image dimensions\n");
   H->dims[0] = rows;
   H->dims[1] = cols;
   H->dims[2] = 3;
   H->size = 3*rows*cols;
   H->R = (double *)calloc(H->size, sizeof(double));
   if (!H->R)
      sip_error("unable to alloc memory for the return image\n");

   // SetImageType(image,TrueColorType);
   for (i=0; i< rows; i++)
      for (j=0; j< cols; j++) {
         RC3DbyC(H->R,i,j,0,rows,cols) = RCbyR(pix,i,j,cols).red   * factor;
         RC3DbyC(H->R,i,j,1,rows,cols) = RCbyR(pix,i,j,cols).green * factor;
         RC3DbyC(H->R,i,j,2,rows,cols) = RCbyR(pix,i,j,cols).blue  * factor;
   }
   H->it = 0; /* real */
   H->I = NULL;

   return true;
}

bool
magick_index_map_to_sci_dbl(char *fname, Image *image, int nv)
{
   IndexPacket    *index;
   ExceptionInfo  exception;

   double *img_index, *map;
   unsigned i,j;
   double factor = 1.0 / MaxRGB;
   int rmap, cmap, rindex,cindex;

#ifndef NDEBUG
   sciprint("Indexed Image\n\r");
#endif

   if((index = GetIndexes(image)) == (IndexPacket *) NULL)
      SIP_MAGICK_ERROR;
   
   rindex = image->rows;
   cindex = image->columns;
   img_index = (double *)calloc(rindex*cindex, sizeof(double));
   if (!img_index)
      sip_error("unable to alloc memory for output image indexes");
   for (i=0; i< (unsigned)rindex; i++)
      for (j=0; j< (unsigned)cindex; j++)
         IndexImgByCol(img_index,i,j) = IndexImgByRow(index,i,j) + 1;
     
   CreateVarFromPtr(nv++, "d",&rindex,&cindex,&img_index);  
   free(img_index);
   
   rmap = image->colors; cmap = 3;
   map = (double *)calloc(rmap*3, sizeof(double));
   if (!map)
      sip_error("unable to alloc memory for output colormap");
   for (i=0; i < (unsigned) rmap; i++) {
      map[i]        = image->colormap[i].red   * factor;
      map[i+rmap]   = image->colormap[i].green * factor;
      map[i+2*rmap] = image->colormap[i].blue  * factor;
   }
   CreateVarFromPtr(nv, "d",&rmap,&cmap,&map);  /* colormap */
   
   free(map);
   return true;
}

bool
animal_grayscale_image_to_double_array(char *fname,Img *img, double **ptr) 
{
   unsigned i,npts;
   double *pt;


   npts = img->rows*img->cols;
   pt = (double *)calloc(npts, sizeof(double));
      if (!pt) sip_error("unable to alloc memory");

   for (i=0; i<npts; ++i)
      pt[i] = DATA(img)[i];

   *ptr = pt;

   return true;
}

bool
animal_grayscale_imgpuint32_to_double_array(char *fname, ImgPUInt32 *img, double **ptr) 
{
   unsigned i,npts;
   double *pt;


   npts = img->rows*img->cols;
   pt = (double *)calloc(npts, sizeof(double));
      if (!pt) sip_error("unable to alloc memory");

   for (i=0; i<npts; ++i)
      pt[i] = DATA(img)[i];

   *ptr = pt;

   return true;
}
